#!/bin/bash

## IO-helpers
#
utils_dir=$(dirname "${BASH_SOURCE[0]}")

# Load Colors
source ${utils_dir}/colors.sh

function ioNewLine() {
  local __END=${1:-1}

  if [[ "${__END}" -gt 1 ]]; then
    for i in $(seq 1 ${__END}); do echo ""; done
  else
    echo ""
  fi
}

function ioWriteLn() {
  local __M=$1
  local __TYPE=$2

  if [[ -z ${__TYPE} ]]; then
    echo "${__M}"
  else
    echo "${__TYPE}${__M}${RESET}"
  fi
}

function ioBlock() {
  ioNewLine
  for __M in "$@"; do ioWriteLn "${__M}"; done
}

function ioTypeBlock() {
  local __TYPE=$1
  shift
  ioNewLine
  for __M in "$@"; do ioWriteLn "${__M}" "${__TYPE}"; done
}

function ioText() {
  for __M in "$@"; do ioWriteLn "${__M}"; done
}

## Message types
function ioCaution() {
  local __M=$1
  shift
  ioTypeBlock ${YELLOW} "[CAUTION] ${__M}" "$@"
}

function ioError() {
  local __M=$1
  shift
  ioTypeBlock ${RED} "[ERROR] ${__M}" "$@"
}

function ioSuccess() {
  local __M=$1
  shift
  ioTypeBlock ${GREEN} "[OK] ${__M}" "$@"
}

function ioWarning() {
  local __M=$1
  shift
  ioTypeBlock ${RED} "[WARNING] ${__M}" "$@"
}

function ioInfo() {
  local __M=$1
  shift
  ioBlock "${BOLD}[INFO]${RESET} ${__M}" "$@"
}


function ioNote() {
  ioBlock "${BOLD}NOTE: ${RESET} " \
          "========= " \
          "$@"
}

function ioQuickNote() {
  local __M=$1
  shift
  ioTypeBlock ${YELLOW} "[NOTE] ${__M}" "$@"
}

## Inputs
function ioConfirm() {
  # call with a prompt string or use a default
  read -r -p "${1:-Are you sure?} [y/N]: " response
  case "$response" in
  [yY][eE][sS] | [yY])
    true
    ;;
  *)
    false
    ;;
  esac
}
