#!/bin/bash
SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" >/dev/null 2>&1 && pwd)"

set -e

cwd=$(pwd)

# Load colors and the I/O functions
source ${SCRIPT_DIR}/utils/io.sh

source ${SCRIPT_DIR}/functions.sh

FORCE=false
INTERACTION=true
WordpressDir="${cwd}/www"

function usage() {
  echo "${YELLOW}Description: ${RESET}"
  echo "    Remove Wordpress related files. "
  echo ""
  echo "${YELLOW}Usage: ${RESET}"
  echo "    ./bin/wordpress-remove.sh [options]"
  echo ""
  echo "${YELLOW}Options: ${RESET}"
  echo "   ${GREEN} -f, --force          ${RESET} Force remove"
  echo "   ${GREEN} -h, --help           ${RESET} Display this help message"
  echo "   ${GREEN} -n, --no-interaction ${RESET} Do not ask any interactive question"
}

# Read arguments
POSITIONAL=()
while [[ $# -gt 0 ]]; do
  key="$1"
  case $key in
  -f | --force)
    FORCE=true
    shift # past argument
    ;;
  -h | --help)
    usage
    exit 0
    shift # past argument
    ;;
  -n | --no-interaction)
    INTERACTION=false
    shift # past argument
    ;;
  *) # unknown option
    POSITIONAL+=("$1") # save it in an array for later
    shift              # past argument
    ;;
  esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters
# Done reading arguments

if [[ ! -f "${WordpressDir}/wp-blog-header.php" ]]; then
  ioInfo "No Wordpress installation found! Nothing was removed."
  exit 0
fi

if [[ ${FORCE} != true ]] && [[ ${INTERACTION} == true ]]; then
  ioConfirm || ioInfo "Nothing removed. Have a nice day!"; exit 0
fi

removeWordpress ${WordpressDir}
